Experience class
Constructors
-
Experience({required String id, required String name, required ExperienceType type, required ExperienceFamily? family, required String? placement, required String? contentUrl, required ExperienceContentType contentType, required Map<
String, dynamic> ? features, required String? strategy, required List<ExperienceSelector> ? selectors, required List<ExperienceFilter> ? filters, required Map<String, dynamic> rawJson, String? resolvedContent}) - Experience.fromMap(Map m)
-
factory
Properties
- contentType → ExperienceContentType
-
final
- contentUrl → String?
-
final
- family → ExperienceFamily?
-
final
-
features
→ Map<
String, dynamic> ? -
final
-
filters
→ List<
ExperienceFilter> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
final
- name → String
-
final
- placement → String?
-
final
-
rawJson
→ Map<
String, dynamic> -
final
- resolvedContent ↔ String?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
selectors
→ List<
ExperienceSelector> ? -
final
- strategy → String?
-
final
- type → ExperienceType
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited